<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('delivery');

// 记录访问日志
record_log('访问配送任务管理页面');

// 处理任务分配
if (isset($_GET['action']) && $_GET['action'] == 'assign' && isset($_GET['id'])) {
    $task_id = intval($_GET['id']);

    // 获取可用配送员
    $stmt = $pdo->query("
        SELECT s.* FROM delivery_staff s
        WHERE s.status = 1
        ORDER BY s.avg_rating DESC
    ");
    $staff_list = $stmt->fetchAll();

    // 获取任务详情
    $stmt = $pdo->prepare("
        SELECT t.*, o.order_no, o.member_id, o.total_amount, o.status as order_status,
               m.name as member_name, m.phone as member_phone
        FROM delivery_tasks t
        JOIN orders o ON t.order_id = o.id
        LEFT JOIN members m ON o.member_id = m.id
        WHERE t.id = ?
    ");
    $stmt->execute([$task_id]);
    $task = $stmt->fetch();

    if (!$task) {
        $error_message = "任务不存在";
        // 不再重定向
    }

    // 处理提交的配送员分配
    if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['staff_id'])) {
        $staff_id = intval($_POST['staff_id']);

        $stmt = $pdo->prepare("
            UPDATE delivery_tasks
            SET staff_id = ?, status = 2, update_time = NOW()
            WHERE id = ? AND status = 1
        ");
        $result = $stmt->execute([$staff_id, $task_id]);

        if ($result) {
            record_log("分配配送任务 #{$task_id} 给配送员ID: {$staff_id}");
            $success_message = "配送任务分配成功";
            // 重定向到列表页面并携带成功消息
            header("Location: task.php?success=" . urlencode($success_message));
            exit;
        } else {
            $error_message = "配送任务分配失败，请重试";
        }
    }
}
// 处理任务状态更新
elseif (isset($_GET['action']) && $_GET['action'] == 'update' && isset($_GET['id'])) {
    $task_id = intval($_GET['id']);

    // 获取任务详情
    $stmt = $pdo->prepare("
        SELECT t.*, o.order_no, o.member_id, o.total_amount, o.status as order_status,
               m.name as member_name, m.phone as member_phone,
               s.name as staff_name
        FROM delivery_tasks t
        JOIN orders o ON t.order_id = o.id
        LEFT JOIN members m ON o.member_id = m.id
        LEFT JOIN delivery_staff s ON t.staff_id = s.id
        WHERE t.id = ?
    ");
    $stmt->execute([$task_id]);
    $task = $stmt->fetch();

    if (!$task) {
        $error_message = "任务不存在";
        // 不再重定向
    }

    // 处理提交的状态更新
    if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['new_status'])) {
        $new_status = intval($_POST['new_status']);
        $remark = isset($_POST['remark']) ? $_POST['remark'] : null;

        // 开始事务
        $pdo->beginTransaction();

        try {
            // 更新配送任务状态
            $stmt = $pdo->prepare("
                UPDATE delivery_tasks
                SET status = ?, remark = ?, update_time = NOW()
                WHERE id = ?
            ");
            $stmt->execute([$new_status, $remark, $task_id]);

            // 如果配送成功，更新订单状态为已完成
            if ($new_status == 3 && $task['order_status'] == 3) {
                $stmt = $pdo->prepare("
                    UPDATE orders
                    SET status = 4, update_time = NOW()
                    WHERE id = ?
                ");
                $stmt->execute([$task['order_id']]);
            }

            // 如果配送失败，记录原因
            if ($new_status == 5) {
                record_log("配送任务 #{$task_id} 失败，原因：{$remark}");
            }

            $pdo->commit();
            $success_message = "配送状态更新成功";
            // 重定向到列表页面并携带成功消息
            header("Location: task.php?success=" . urlencode($success_message));
            exit;
        } catch (Exception $e) {
            $pdo->rollBack();
            $error_message = "配送状态更新失败：" . $e->getMessage();
        }
    }
}
// 处理任务删除
elseif (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $task_id = intval($_GET['id']);

    // 检查任务是否存在
    $stmt = $pdo->prepare("SELECT id FROM delivery_tasks WHERE id = ?");
    $stmt->execute([$task_id]);

    if ($stmt->rowCount() > 0) {
        $stmt = $pdo->prepare("DELETE FROM delivery_tasks WHERE id = ? AND status IN (1, 5)");
        $result = $stmt->execute([$task_id]);

        if ($result) {
            record_log("删除配送任务 #{$task_id}");
            $success_message = "配送任务已删除";
            // 重定向到列表页面并携带成功消息
            header("Location: task.php?success=" . urlencode($success_message));
            exit;
        } else {
            $error_message = "只能删除待分配或失败的配送任务";
        }
    } else {
        $error_message = "任务不存在";
    }
}

// 处理任务查看
$task_detail = null;
if (isset($_GET['action']) && $_GET['action'] == 'view' && isset($_GET['id'])) {
    $task_id = intval($_GET['id']);

    $stmt = $pdo->prepare("
        SELECT t.*, o.order_no, o.member_id, o.total_amount, o.status as order_status,
               m.name as member_name, m.phone as member_phone,
               s.name as staff_name, s.phone as staff_phone
        FROM delivery_tasks t
        JOIN orders o ON t.order_id = o.id
        LEFT JOIN members m ON o.member_id = m.id
        LEFT JOIN delivery_staff s ON t.staff_id = s.id
        WHERE t.id = ?
    ");
    $stmt->execute([$task_id]);
    $task_detail = $stmt->fetch();

    if (!$task_detail) {
        $error_message = "任务不存在";
    } else {
        // 获取订单商品
        $stmt = $pdo->prepare("
            SELECT i.*, p.name as product_name
            FROM order_items i
            JOIN products p ON i.product_id = p.id
            WHERE i.order_id = ?
        ");
        $stmt->execute([$task_detail['order_id']]);
        $order_items = $stmt->fetchAll();
    }
}

// 从URL参数中获取成功消息
if (isset($_GET['success'])) {
    $success_message = $_GET['success'];
}

// 配送任务列表筛选
$where_conditions = [];
$params = [];

// 筛选条件处理
if ($_SERVER['REQUEST_METHOD'] == 'GET' && isset($_GET['filter'])) {
    if (!empty($_GET['status']) && $_GET['status'] != 'all') {
        $where_conditions[] = "t.status = ?";
        $params[] = intval($_GET['status']);
    }

    if (!empty($_GET['delivery_type']) && $_GET['delivery_type'] != 'all') {
        $where_conditions[] = "t.delivery_type = ?";
        $params[] = intval($_GET['delivery_type']);
    }

    if (!empty($_GET['date_from'])) {
        $where_conditions[] = "DATE(t.create_time) >= ?";
        $params[] = $_GET['date_from'];
    }

    if (!empty($_GET['date_to'])) {
        $where_conditions[] = "DATE(t.create_time) <= ?";
        $params[] = $_GET['date_to'];
    }

    if (!empty($_GET['order_no'])) {
        $where_conditions[] = "o.order_no LIKE ?";
        $params[] = '%' . $_GET['order_no'] . '%';
    }
}

// 构建SQL查询
$where_clause = !empty($where_conditions) ? ' WHERE ' . implode(' AND ', $where_conditions) : '';
$sql = "
    SELECT t.*, o.order_no, s.name as staff_name
    FROM delivery_tasks t
    JOIN orders o ON t.order_id = o.id
    LEFT JOIN delivery_staff s ON t.staff_id = s.id
    {$where_clause}
    ORDER BY t.create_time DESC
";

// 执行查询
$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$tasks = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>配送任务管理</h2>
            <div class="breadcrumb">
                <a href="index.php">配送管理</a> &gt;
                <span>配送任务</span>
            </div>
        </div>

        <div class="content">
            <?php if (isset($error_message)): ?>
                <div class="alert alert-danger"><?php echo $error_message; ?></div>
            <?php endif; ?>

            <?php if (isset($success_message)): ?>
                <div class="alert alert-success"><?php echo $success_message; ?></div>
            <?php endif; ?>

            <?php if (isset($_GET['action']) && $_GET['action'] == 'assign'): ?>
                <!-- 配送任务分配表单 -->
                <div class="form-container">
                    <h3>为订单 <?php echo $task['order_no']; ?> 分配配送员</h3>
                    <form method="post">
                        <div class="form-group">
                            <label>配送地址</label>
                            <input type="text" value="<?php echo $task['route_info']; ?>" readonly>
                        </div>
                        <div class="form-group">
                            <label>配送类型</label>
                            <input type="text" value="<?php echo $task['delivery_type'] == 1 ? '即时配送' : '预约配送'; ?>" readonly>
                        </div>
                        <div class="form-group">
                            <label>预计送达时间</label>
                            <input type="text" value="<?php echo date('Y-m-d H:i', strtotime($task['expected_time'])); ?>" readonly>
                        </div>
                        <div class="form-group">
                            <label>收件人信息</label>
                            <input type="text" value="<?php echo $task['member_name'] ? $task['member_name'] . ' - ' . $task['member_phone'] : '非会员订单'; ?>" readonly>
                        </div>
                        <div class="form-group">
                            <label for="staff_id">选择配送员 <span class="text-danger">*</span></label>
                            <select name="staff_id" id="staff_id" required>
                                <option value="">请选择配送员</option>
                                <?php foreach ($staff_list as $staff): ?>
                                    <option value="<?php echo $staff['id']; ?>">
                                        <?php echo $staff['name']; ?> (<?php echo $staff['phone']; ?>) -
                                        平均评分: <?php echo $staff['avg_rating']; ?> -
                                        负责区域: <?php echo $staff['area']; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary">确认分配</button>
                            <a href="task.php" class="btn btn-secondary">返回列表</a>
                        </div>
                    </form>
                </div>
            <?php elseif (isset($_GET['action']) && $_GET['action'] == 'update'): ?>
                <!-- 配送状态更新表单 -->
                <div class="form-container">
                    <h3>更新配送任务状态</h3>
                    <form method="post">
                        <div class="form-group">
                            <label>订单编号</label>
                            <input type="text" value="<?php echo $task['order_no']; ?>" readonly>
                        </div>
                        <div class="form-group">
                            <label>配送地址</label>
                            <input type="text" value="<?php echo $task['route_info']; ?>" readonly>
                        </div>
                        <div class="form-group">
                            <label>配送员</label>
                            <input type="text" value="<?php echo $task['staff_name']; ?>" readonly>
                        </div>
                        <div class="form-group">
                            <label>当前状态</label>
                            <input type="text" value="<?php
                                                        switch ($task['status']) {
                                                            case 1:
                                                                echo '待分配';
                                                                break;
                                                            case 2:
                                                                echo '配送中';
                                                                break;
                                                            case 3:
                                                                echo '已送达';
                                                                break;
                                                            case 4:
                                                                echo '已确认';
                                                                break;
                                                            case 5:
                                                                echo '配送失败';
                                                                break;
                                                            default:
                                                                echo '未知状态';
                                                        }
                                                        ?>" readonly>
                        </div>
                        <div class="form-group">
                            <label for="new_status">更新状态为 <span class="text-danger">*</span></label>
                            <select name="new_status" id="new_status" required>
                                <option value="">请选择新状态</option>
                                <?php if ($task['status'] == 2): ?>
                                    <option value="3">已送达</option>
                                    <option value="5">配送失败</option>
                                <?php elseif ($task['status'] == 3): ?>
                                    <option value="4">已确认</option>
                                    <option value="5">配送失败</option>
                                <?php endif; ?>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="remark">备注</label>
                            <input type="text" name="remark" id="remark" placeholder="请输入备注信息或失败原因">
                        </div>
                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary">确认更新</button>
                            <a href="task.php" class="btn btn-secondary">返回列表</a>
                        </div>
                    </form>
                </div>
            <?php elseif (isset($_GET['action']) && $_GET['action'] == 'view' && $task_detail): ?>
                <!-- 配送任务详情 -->
                <div class="form-container">
                    <h3>配送任务详情</h3>
                    <div class="system-info">
                        <table class="info-table">
                            <tr>
                                <td width="150">订单编号：</td>
                                <td><?php echo $task_detail['order_no']; ?></td>
                            </tr>
                            <tr>
                                <td>配送地址：</td>
                                <td><?php echo $task_detail['route_info']; ?></td>
                            </tr>
                            <tr>
                                <td>配送类型：</td>
                                <td><?php echo $task_detail['delivery_type'] == 1 ? '即时配送' : '预约配送'; ?></td>
                            </tr>
                            <tr>
                                <td>预计送达时间：</td>
                                <td><?php echo date('Y-m-d H:i', strtotime($task_detail['expected_time'])); ?></td>
                            </tr>
                            <tr>
                                <td>收件人信息：</td>
                                <td>
                                    <?php if ($task_detail['member_name']): ?>
                                        <?php echo $task_detail['member_name']; ?> (<?php echo $task_detail['member_phone']; ?>)
                                    <?php else: ?>
                                        非会员订单
                                    <?php endif; ?>
                                </td>
                            </tr>
                            <tr>
                                <td>配送员：</td>
                                <td>
                                    <?php if ($task_detail['staff_name']): ?>
                                        <?php echo $task_detail['staff_name']; ?> (<?php echo $task_detail['staff_phone']; ?>)
                                    <?php else: ?>
                                        尚未分配
                                    <?php endif; ?>
                                </td>
                            </tr>
                            <tr>
                                <td>订单金额：</td>
                                <td>￥<?php echo number_format($task_detail['total_amount'], 2); ?></td>
                            </tr>
                            <tr>
                                <td>配送状态：</td>
                                <td>
                                    <?php
                                    $status_text = '';
                                    switch ($task_detail['status']) {
                                        case 1:
                                            $status_text = '待分配';
                                            break;
                                        case 2:
                                            $status_text = '配送中';
                                            break;
                                        case 3:
                                            $status_text = '已送达';
                                            break;
                                        case 4:
                                            $status_text = '已确认';
                                            break;
                                        case 5:
                                            $status_text = '配送失败';
                                            break;
                                        default:
                                            $status_text = '未知状态';
                                    }
                                    echo $status_text;
                                    ?>
                                </td>
                            </tr>
                            <tr>
                                <td>备注：</td>
                                <td><?php echo $task_detail['remark'] ?: '无'; ?></td>
                            </tr>
                            <tr>
                                <td>创建时间：</td>
                                <td><?php echo $task_detail['create_time']; ?></td>
                            </tr>
                            <tr>
                                <td>最后更新：</td>
                                <td><?php echo $task_detail['update_time']; ?></td>
                            </tr>
                        </table>
                    </div>

                    <h3 style="margin-top: 20px;">订单商品</h3>
                    <div class="table-container">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>商品名称</th>
                                    <th>数量</th>
                                    <th>单价</th>
                                    <th>小计</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($order_items as $item): ?>
                                    <tr>
                                        <td><?php echo $item['product_name']; ?></td>
                                        <td><?php echo $item['quantity']; ?></td>
                                        <td>￥<?php echo number_format($item['price'], 2); ?></td>
                                        <td>￥<?php echo number_format($item['subtotal'], 2); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <div class="form-actions">
                        <?php if ($task_detail['status'] == 1): ?>
                            <a href="task.php?action=assign&id=<?php echo $task_detail['id']; ?>" class="btn btn-primary">分配配送员</a>
                        <?php elseif ($task_detail['status'] == 2 || $task_detail['status'] == 3): ?>
                            <a href="task.php?action=update&id=<?php echo $task_detail['id']; ?>" class="btn btn-primary">更新状态</a>
                        <?php endif; ?>
                        <a href="task.php" class="btn btn-secondary">返回列表</a>
                    </div>
                </div>
            <?php else: ?>
                <!-- 配送任务列表 -->
                <div class="action-bar">
                    <a href="create_delivery_task.php" class="btn btn-primary">添加配送任务</a>
                </div>

                <div class="filter-form">
                    <form method="get" action="task.php">
                        <input type="hidden" name="filter" value="1">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="status">配送状态</label>
                                <select name="status" id="status">
                                    <option value="all">全部状态</option>
                                    <option value="1" <?php echo (isset($_GET['status']) && $_GET['status'] == '1') ? 'selected' : ''; ?>>待分配</option>
                                    <option value="2" <?php echo (isset($_GET['status']) && $_GET['status'] == '2') ? 'selected' : ''; ?>>配送中</option>
                                    <option value="3" <?php echo (isset($_GET['status']) && $_GET['status'] == '3') ? 'selected' : ''; ?>>已送达</option>
                                    <option value="4" <?php echo (isset($_GET['status']) && $_GET['status'] == '4') ? 'selected' : ''; ?>>已确认</option>
                                    <option value="5" <?php echo (isset($_GET['status']) && $_GET['status'] == '5') ? 'selected' : ''; ?>>配送失败</option>
                                </select>
                            </div>
                            <div class="filter-item">
                                <label for="delivery_type">配送类型</label>
                                <select name="delivery_type" id="delivery_type">
                                    <option value="all">全部类型</option>
                                    <option value="1" <?php echo (isset($_GET['delivery_type']) && $_GET['delivery_type'] == '1') ? 'selected' : ''; ?>>即时配送</option>
                                    <option value="2" <?php echo (isset($_GET['delivery_type']) && $_GET['delivery_type'] == '2') ? 'selected' : ''; ?>>预约配送</option>
                                </select>
                            </div>
                            <div class="filter-item">
                                <label for="order_no">订单编号</label>
                                <input type="text" name="order_no" id="order_no" value="<?php echo isset($_GET['order_no']) ? $_GET['order_no'] : ''; ?>">
                            </div>
                        </div>
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="date_from">开始日期</label>
                                <input type="date" name="date_from" id="date_from" value="<?php echo isset($_GET['date_from']) ? $_GET['date_from'] : ''; ?>">
                            </div>
                            <div class="filter-item">
                                <label for="date_to">结束日期</label>
                                <input type="date" name="date_to" id="date_to" value="<?php echo isset($_GET['date_to']) ? $_GET['date_to'] : ''; ?>">
                            </div>
                            <div class="filter-item" style="display: flex; align-items: flex-end;">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="task.php" class="btn btn-secondary" style="margin-left: 10px;">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>订单编号</th>
                                <th>配送类型</th>
                                <th>预计送达时间</th>
                                <th>配送地址</th>
                                <th>配送员</th>
                                <th>状态</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($tasks) > 0): ?>
                                <?php foreach ($tasks as $task): ?>
                                    <tr>
                                        <td><?php echo $task['id']; ?></td>
                                        <td><?php echo $task['order_no']; ?></td>
                                        <td><?php echo $task['delivery_type'] == 1 ? '即时配送' : '预约配送'; ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($task['expected_time'])); ?></td>
                                        <td><?php echo $task['route_info']; ?></td>
                                        <td><?php echo $task['staff_name'] ?: '未分配'; ?></td>
                                        <td>
                                            <?php
                                            $status_class = '';
                                            switch ($task['status']) {
                                                case 1:
                                                    echo '待分配';
                                                    $status_class = 'text-warning';
                                                    break;
                                                case 2:
                                                    echo '配送中';
                                                    $status_class = 'text-primary';
                                                    break;
                                                case 3:
                                                    echo '已送达';
                                                    $status_class = 'text-success';
                                                    break;
                                                case 4:
                                                    echo '已确认';
                                                    $status_class = 'status-active';
                                                    break;
                                                case 5:
                                                    echo '配送失败';
                                                    $status_class = 'status-inactive';
                                                    break;
                                                default:
                                                    echo '未知状态';
                                            }
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($task['create_time'])); ?></td>
                                        <td>
                                            <a href="task.php?action=view&id=<?php echo $task['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                            <?php if ($task['status'] == 1): ?>
                                                <a href="task.php?action=assign&id=<?php echo $task['id']; ?>" class="btn btn-sm btn-primary">分配</a>
                                            <?php elseif ($task['status'] == 2 || $task['status'] == 3): ?>
                                                <a href="task.php?action=update&id=<?php echo $task['id']; ?>" class="btn btn-sm btn-primary">更新</a>
                                            <?php endif; ?>
                                            <?php if ($task['status'] == 1 || $task['status'] == 5): ?>
                                                <a href="javascript:void(0);" onclick="if(confirm('确定要删除这个配送任务吗？')) window.location.href='task.php?action=delete&id=<?php echo $task['id']; ?>';" class="btn btn-sm btn-danger">删除</a>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="9" class="text-center">没有找到配送任务</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>