<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('delivery');

// 记录访问日志
record_log('访问配送状态跟踪页面');

// 处理客户确认送达
if (isset($_GET['action']) && $_GET['action'] == 'confirm' && isset($_GET['id'])) {
    $task_id = intval($_GET['id']);

    // 检查任务状态是否为已送达
    $stmt = $pdo->prepare("
        SELECT t.*, o.order_no, o.member_id
        FROM delivery_tasks t
        JOIN orders o ON t.order_id = o.id
        WHERE t.id = ? AND t.status = 3
    ");
    $stmt->execute([$task_id]);
    $task = $stmt->fetch();

    if (!$task) {
        $error_message = "任务不存在或状态不正确";
        // 不再重定向
    }

    // 处理客户确认
    if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['rating'])) {
        $rating = intval($_POST['rating']);
        $comment = isset($_POST['comment']) ? $_POST['comment'] : '';

        $pdo->beginTransaction();

        try {
            // 更新任务状态为已确认
            $stmt = $pdo->prepare("
                UPDATE delivery_tasks
                SET status = 4, update_time = NOW()
                WHERE id = ?
            ");
            $stmt->execute([$task_id]);

            // 记录配送评价
            $stmt = $pdo->prepare("
                INSERT INTO delivery_ratings (task_id, staff_id, rating, comment, create_time)
                VALUES (?, ?, ?, ?, NOW())
            ");
            $stmt->execute([$task_id, $task['staff_id'], $rating, $comment]);

            // 更新配送员平均评分
            $stmt = $pdo->prepare("
                UPDATE delivery_staff
                SET avg_rating = (
                    SELECT AVG(rating) FROM delivery_ratings WHERE staff_id = ?
                )
                WHERE id = ?
            ");
            $stmt->execute([$task['staff_id'], $task['staff_id']]);

            $pdo->commit();
            record_log("配送任务 #{$task_id} 已确认完成，评分：{$rating}");
            $success_message = "配送确认成功，感谢您的评价";
            // 重定向到列表页面并携带成功消息
            header("Location: track.php?success=" . urlencode($success_message));
            exit;
        } catch (Exception $e) {
            $pdo->rollBack();
            $error_message = "确认失败：" . $e->getMessage();
        }
    }
}

// 处理配送异常
if (isset($_GET['action']) && $_GET['action'] == 'exception' && isset($_GET['id'])) {
    $task_id = intval($_GET['id']);

    // 检查任务是否存在
    $stmt = $pdo->prepare("
        SELECT t.*, o.order_no, s.name as staff_name
        FROM delivery_tasks t
        JOIN orders o ON t.order_id = o.id
        LEFT JOIN delivery_staff s ON t.staff_id = s.id
        WHERE t.id = ? AND t.status IN (2, 3)
    ");
    $stmt->execute([$task_id]);
    $task = $stmt->fetch();

    if (!$task) {
        $error_message = "任务不存在或状态不正确";
        // 不再重定向
    }

    // 处理提交的异常信息
    if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['exception_type']) && isset($_POST['exception_desc'])) {
        $exception_type = $_POST['exception_type'];
        $exception_desc = $_POST['exception_desc'];

        $pdo->beginTransaction();

        try {
            // 更新任务状态为配送失败
            $stmt = $pdo->prepare("
                UPDATE delivery_tasks
                SET status = 5, remark = ?, update_time = NOW()
                WHERE id = ?
            ");
            $stmt->execute(["【{$exception_type}】{$exception_desc}", $task_id]);

            $pdo->commit();
            record_log("配送任务 #{$task_id} 发生异常：{$exception_type} - {$exception_desc}");
            $success_message = "异常信息已记录，配送状态已更新";
            // 重定向到列表页面并携带成功消息
            header("Location: track.php?success=" . urlencode($success_message));
            exit;
        } catch (Exception $e) {
            $pdo->rollBack();
            $error_message = "记录异常失败：" . $e->getMessage();
        }
    }
}

// 从URL参数中获取成功消息
if (isset($_GET['success'])) {
    $success_message = $_GET['success'];
}

// 配送任务查询
$search_type = isset($_GET['search_type']) ? $_GET['search_type'] : '';
$search_value = isset($_GET['search_value']) ? trim($_GET['search_value']) : '';
$tasks = [];

if (!empty($search_type) && !empty($search_value)) {
    switch ($search_type) {
        case 'order_no':
            $stmt = $pdo->prepare("
                SELECT t.*, o.order_no, o.member_id, s.name as staff_name, s.phone as staff_phone
                FROM delivery_tasks t
                JOIN orders o ON t.order_id = o.id
                LEFT JOIN delivery_staff s ON t.staff_id = s.id
                WHERE o.order_no LIKE ?
                ORDER BY t.create_time DESC
            ");
            $stmt->execute(["%{$search_value}%"]);
            break;

        case 'phone':
            $stmt = $pdo->prepare("
                SELECT t.*, o.order_no, o.member_id, s.name as staff_name, s.phone as staff_phone
                FROM delivery_tasks t
                JOIN orders o ON t.order_id = o.id
                LEFT JOIN delivery_staff s ON t.staff_id = s.id
                LEFT JOIN members m ON o.member_id = m.id
                WHERE m.phone LIKE ?
                ORDER BY t.create_time DESC
            ");
            $stmt->execute(["%{$search_value}%"]);
            break;

        case 'address':
            $stmt = $pdo->prepare("
                SELECT t.*, o.order_no, o.member_id, s.name as staff_name, s.phone as staff_phone
                FROM delivery_tasks t
                JOIN orders o ON t.order_id = o.id
                LEFT JOIN delivery_staff s ON t.staff_id = s.id
                WHERE t.route_info LIKE ?
                ORDER BY t.create_time DESC
            ");
            $stmt->execute(["%{$search_value}%"]);
            break;

        case 'task_id':
            $stmt = $pdo->prepare("
                SELECT t.*, o.order_no, o.member_id, s.name as staff_name, s.phone as staff_phone
                FROM delivery_tasks t
                JOIN orders o ON t.order_id = o.id
                LEFT JOIN delivery_staff s ON t.staff_id = s.id
                WHERE t.id = ?
                ORDER BY t.create_time DESC
            ");
            $stmt->execute([intval($search_value)]);
            break;
    }

    if (isset($stmt)) {
        $tasks = $stmt->fetchAll();
    }
}

// 获取最近的配送任务
$stmt = $pdo->query("
    SELECT t.*, o.order_no, s.name as staff_name
    FROM delivery_tasks t
    JOIN orders o ON t.order_id = o.id
    LEFT JOIN delivery_staff s ON t.staff_id = s.id
    ORDER BY t.create_time DESC
    LIMIT 10
");
$recent_tasks = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>配送状态跟踪</h2>
            <div class="breadcrumb">
                <a href="../index.php">首页</a> &gt;
                <a href="index.php">配送管理</a> &gt;
                <span>配送状态跟踪</span>
            </div>
        </div>

        <div class="content">
            <?php if (isset($error_message)): ?>
                <div class="alert alert-danger"><?php echo $error_message; ?></div>
            <?php endif; ?>

            <?php if (isset($success_message)): ?>
                <div class="alert alert-success"><?php echo $success_message; ?></div>
            <?php endif; ?>

            <?php if (isset($_GET['action']) && $_GET['action'] == 'confirm' && isset($task)): ?>
                <!-- 客户确认送达 -->
                <div class="form-container">
                    <h3>确认订单 <?php echo $task['order_no']; ?> 已送达并评价</h3>
                    <form method="post">
                        <div class="form-group">
                            <label>订单信息</label>
                            <input type="text" value="<?php echo $task['order_no']; ?>" readonly>
                        </div>
                        <div class="form-group">
                            <label for="rating">配送服务评分 <span class="text-danger">*</span></label>
                            <select name="rating" id="rating" required>
                                <option value="5">5分 (非常满意)</option>
                                <option value="4">4分 (满意)</option>
                                <option value="3">3分 (一般)</option>
                                <option value="2">2分 (不满意)</option>
                                <option value="1">1分 (非常不满意)</option>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="comment">评价内容</label>
                            <input type="text" name="comment" id="comment" placeholder="请输入您对此次配送的评价">
                        </div>
                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary">确认并评价</button>
                            <a href="track.php" class="btn btn-secondary">返回</a>
                        </div>
                    </form>
                </div>
            <?php elseif (isset($_GET['action']) && $_GET['action'] == 'exception' && isset($task)): ?>
                <!-- 配送异常处理 -->
                <div class="form-container">
                    <h3>记录配送异常 - 订单 <?php echo $task['order_no']; ?></h3>
                    <form method="post">
                        <div class="form-group">
                            <label>订单信息</label>
                            <input type="text" value="<?php echo $task['order_no']; ?>" readonly>
                        </div>
                        <div class="form-group">
                            <label>配送地址</label>
                            <input type="text" value="<?php echo $task['route_info']; ?>" readonly>
                        </div>
                        <div class="form-group">
                            <label>配送员</label>
                            <input type="text" value="<?php echo $task['staff_name'] ?: '未分配'; ?>" readonly>
                        </div>
                        <div class="form-group">
                            <label for="exception_type">异常类型 <span class="text-danger">*</span></label>
                            <select name="exception_type" id="exception_type" required>
                                <option value="">请选择异常类型</option>
                                <option value="收件人不在">收件人不在</option>
                                <option value="地址错误">地址错误</option>
                                <option value="联系不上收件人">联系不上收件人</option>
                                <option value="商品损坏">商品损坏</option>
                                <option value="客户拒收">客户拒收</option>
                                <option value="其他异常">其他异常</option>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="exception_desc">异常详细描述 <span class="text-danger">*</span></label>
                            <input type="text" name="exception_desc" id="exception_desc" required placeholder="请详细描述异常情况">
                        </div>
                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary">提交异常记录</button>
                            <a href="track.php" class="btn btn-secondary">返回</a>
                        </div>
                    </form>
                </div>
            <?php else: ?>
                <!-- 配送查询 -->
                <div class="filter-form">
                    <h3>配送状态查询</h3>
                    <form method="get" action="track.php">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="search_type">查询类型</label>
                                <select name="search_type" id="search_type" required>
                                    <option value="order_no" <?php echo $search_type == 'order_no' ? 'selected' : ''; ?>>订单编号</option>
                                    <option value="phone" <?php echo $search_type == 'phone' ? 'selected' : ''; ?>>手机号码</option>
                                    <option value="address" <?php echo $search_type == 'address' ? 'selected' : ''; ?>>配送地址</option>
                                    <option value="task_id" <?php echo $search_type == 'task_id' ? 'selected' : ''; ?>>配送任务ID</option>
                                </select>
                            </div>
                            <div class="filter-item">
                                <label for="search_value">查询内容</label>
                                <input type="text" name="search_value" id="search_value" value="<?php echo htmlspecialchars($search_value); ?>" required placeholder="请输入查询内容">
                            </div>
                            <div class="filter-item" style="display: flex; align-items: flex-end;">
                                <button type="submit" class="btn btn-primary">查询</button>
                                <a href="track.php" class="btn btn-secondary" style="margin-left: 10px;">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <?php if (!empty($search_type) && !empty($search_value)): ?>
                    <!-- 查询结果 -->
                    <h3>查询结果</h3>
                    <div class="table-container">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>任务ID</th>
                                    <th>订单编号</th>
                                    <th>配送类型</th>
                                    <th>配送地址</th>
                                    <th>配送员</th>
                                    <th>预计送达时间</th>
                                    <th>状态</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (count($tasks) > 0): ?>
                                    <?php foreach ($tasks as $task): ?>
                                        <tr>
                                            <td><?php echo $task['id']; ?></td>
                                            <td><?php echo $task['order_no']; ?></td>
                                            <td><?php echo $task['delivery_type'] == 1 ? '即时配送' : '预约配送'; ?></td>
                                            <td><?php echo $task['route_info']; ?></td>
                                            <td><?php echo $task['staff_name'] ?: '未分配'; ?></td>
                                            <td><?php echo date('Y-m-d H:i', strtotime($task['expected_time'])); ?></td>
                                            <td>
                                                <?php
                                                switch ($task['status']) {
                                                    case 1:
                                                        echo '待分配';
                                                        break;
                                                    case 2:
                                                        echo '配送中';
                                                        break;
                                                    case 3:
                                                        echo '已送达';
                                                        break;
                                                    case 4:
                                                        echo '已确认';
                                                        break;
                                                    case 5:
                                                        echo '配送失败';
                                                        break;
                                                    default:
                                                        echo '未知状态';
                                                }
                                                ?>
                                            </td>
                                            <td>
                                                <a href="task.php?action=view&id=<?php echo $task['id']; ?>" class="btn btn-sm btn-secondary">详情</a>
                                                <?php if ($task['status'] == 3): ?>
                                                    <a href="track.php?action=confirm&id=<?php echo $task['id']; ?>" class="btn btn-sm btn-primary">确认送达</a>
                                                <?php endif; ?>
                                                <?php if ($task['status'] == 2 || $task['status'] == 3): ?>
                                                    <a href="track.php?action=exception&id=<?php echo $task['id']; ?>" class="btn btn-sm btn-danger">记录异常</a>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="8" class="text-center">没有找到匹配的配送记录</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>

                <!-- 最近配送任务 -->
                <h3 style="margin-top: 20px;">最近配送任务</h3>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>任务ID</th>
                                <th>订单编号</th>
                                <th>配送类型</th>
                                <th>配送地址</th>
                                <th>配送员</th>
                                <th>状态</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($recent_tasks) > 0): ?>
                                <?php foreach ($recent_tasks as $task): ?>
                                    <tr>
                                        <td><?php echo $task['id']; ?></td>
                                        <td><?php echo $task['order_no']; ?></td>
                                        <td><?php echo $task['delivery_type'] == 1 ? '即时配送' : '预约配送'; ?></td>
                                        <td><?php echo $task['route_info']; ?></td>
                                        <td><?php echo $task['staff_name'] ?: '未分配'; ?></td>
                                        <td>
                                            <?php
                                            $status_class = '';
                                            switch ($task['status']) {
                                                case 1:
                                                    echo '待分配';
                                                    $status_class = 'text-warning';
                                                    break;
                                                case 2:
                                                    echo '配送中';
                                                    $status_class = 'text-primary';
                                                    break;
                                                case 3:
                                                    echo '已送达';
                                                    $status_class = 'text-success';
                                                    break;
                                                case 4:
                                                    echo '已确认';
                                                    $status_class = 'status-active';
                                                    break;
                                                case 5:
                                                    echo '配送失败';
                                                    $status_class = 'status-inactive';
                                                    break;
                                                default:
                                                    echo '未知状态';
                                            }
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($task['create_time'])); ?></td>
                                        <td>
                                            <a href="task.php?action=view&id=<?php echo $task['id']; ?>" class="btn btn-sm btn-secondary">详情</a>
                                            <?php if ($task['status'] == 3): ?>
                                                <a href="track.php?action=confirm&id=<?php echo $task['id']; ?>" class="btn btn-sm btn-primary">确认送达</a>
                                            <?php endif; ?>
                                            <?php if ($task['status'] == 2 || $task['status'] == 3): ?>
                                                <a href="track.php?action=exception&id=<?php echo $task['id']; ?>" class="btn btn-sm btn-danger">记录异常</a>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无配送任务</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 配送状态解释 -->
                <div class="info-box">
                    <h3>配送状态说明</h3>
                    <ul>
                        <li><strong>待分配</strong>：订单已生成配送任务，等待分配配送员</li>
                        <li><strong>配送中</strong>：配送员已接单并开始配送</li>
                        <li><strong>已送达</strong>：配送员已将订单送达指定地址，等待客户确认</li>
                        <li><strong>已确认</strong>：客户已确认收到订单</li>
                        <li><strong>配送失败</strong>：配送过程中发生异常，无法完成配送</li>
                    </ul>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>