<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('marketing');

// 记录访问日志
record_log('访问优惠券管理页面');

// 处理动作参数
$action = isset($_GET['action']) ? $_GET['action'] : 'list';
$success_message = '';
$error_message = '';

// 处理优惠券发放
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['issue_coupon'])) {
    $campaign_id = isset($_POST['campaign_id']) ? intval($_POST['campaign_id']) : 0;
    $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;
    $member_level_id = isset($_POST['member_level_id']) ? intval($_POST['member_level_id']) : 0;

    if ($campaign_id <= 0) {
        $error_message = '请选择优惠券活动';
    } else {
        try {
            $pdo->beginTransaction();

            // 获取活动信息
            $stmt = $pdo->prepare("SELECT * FROM marketing_campaigns WHERE id = ? AND status = 1");
            $stmt->execute([$campaign_id]);
            $campaign = $stmt->fetch();

            if (!$campaign) {
                throw new Exception('选择的活动不存在或已禁用');
            }

            if ($member_id > 0) {
                // 发放给指定会员
                $code = 'C' . time() . rand(1000, 9999);
                $stmt = $pdo->prepare("INSERT INTO member_coupons (member_id, campaign_id, code, create_time) VALUES (?, ?, ?, NOW())");
                $stmt->execute([$member_id, $campaign_id, $code]);
                $affected = 1;

                record_log("为会员ID:$member_id 发放优惠券，活动ID:$campaign_id");
            } else if ($member_level_id > 0) {
                // 发放给指定等级的会员
                $stmt = $pdo->prepare("SELECT id FROM members WHERE level_id = ? AND status = 1");
                $stmt->execute([$member_level_id]);
                $members = $stmt->fetchAll(PDO::FETCH_COLUMN);

                $affected = 0;
                $insert = $pdo->prepare("INSERT INTO member_coupons (member_id, campaign_id, code, create_time) VALUES (?, ?, ?, NOW())");

                foreach ($members as $mid) {
                    $code = 'C' . time() . rand(1000, 9999) . $mid;
                    $insert->execute([$mid, $campaign_id, $code]);
                    $affected++;
                }

                record_log("为会员等级ID:$member_level_id 发放优惠券，活动ID:$campaign_id，共{$affected}张");
            } else {
                // 发放给所有会员
                $stmt = $pdo->prepare("SELECT id FROM members WHERE status = 1");
                $stmt->execute();
                $members = $stmt->fetchAll(PDO::FETCH_COLUMN);

                $affected = 0;
                $insert = $pdo->prepare("INSERT INTO member_coupons (member_id, campaign_id, code, create_time) VALUES (?, ?, ?, NOW())");

                foreach ($members as $mid) {
                    $code = 'C' . time() . rand(1000, 9999) . $mid;
                    $insert->execute([$mid, $campaign_id, $code]);
                    $affected++;
                }

                record_log("为所有会员发放优惠券，活动ID:$campaign_id，共{$affected}张");
            }

            $pdo->commit();
            $success_message = "成功发放{$affected}张优惠券";
        } catch (Exception $e) {
            $pdo->rollBack();
            $error_message = '发放优惠券失败: ' . $e->getMessage();
        }
    }
}

// 获取可用的优惠券活动
$stmt = $pdo->query("
    SELECT * FROM marketing_campaigns 
    WHERE (type IN (1, 2) OR type = 6) 
    AND status = 1 
    AND end_time > NOW() 
    ORDER BY id DESC
");
$coupon_campaigns = $stmt->fetchAll();

// 检查优惠券活动是否存在
$has_coupon_campaigns = !empty($coupon_campaigns);

// 获取会员等级列表
$stmt = $pdo->query("SELECT id, level_name FROM member_levels ORDER BY min_points");
$member_levels = $stmt->fetchAll();

// 查询条件
$where = ["1=1"];
$params = [];

$member_id = isset($_GET['member_id']) ? intval($_GET['member_id']) : 0;
$campaign_id = isset($_GET['campaign_id']) ? intval($_GET['campaign_id']) : 0;
$is_used = isset($_GET['is_used']) ? intval($_GET['is_used']) : -1;

if ($member_id > 0) {
    $where[] = "mc.member_id = ?";
    $params[] = $member_id;
}

if ($campaign_id > 0) {
    $where[] = "mc.campaign_id = ?";
    $params[] = $campaign_id;
}

if ($is_used != -1) {
    $where[] = "mc.is_used = ?";
    $params[] = $is_used;
}

// 分页参数
$page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
$limit = 15;
$offset = ($page - 1) * $limit;

// 获取总记录数
$where_clause = implode(" AND ", $where);
$count_sql = "
    SELECT COUNT(*) AS total 
    FROM member_coupons mc 
    WHERE $where_clause
";
$stmt = $pdo->prepare($count_sql);
$stmt->execute($params);
$total_records = $stmt->fetch()['total'];
$total_pages = ceil($total_records / $limit);

// 获取分页数据
$sql = "
    SELECT mc.*, m.name as member_name, m.phone as member_phone,
           cam.name as campaign_name, cam.type as campaign_type,
           cam.discount_type, cam.discount_value, cam.min_amount
    FROM member_coupons mc
    LEFT JOIN members m ON mc.member_id = m.id
    LEFT JOIN marketing_campaigns cam ON mc.campaign_id = cam.id
    WHERE $where_clause
    ORDER BY mc.id DESC
    LIMIT $offset, $limit
";
$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$coupons = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>优惠券管理</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>优惠券管理</h2>
            <div class="breadcrumb">
                <a href="index.php">营销推广</a> &gt;
                <span>优惠券管理</span>
            </div>
        </div>

        <div class="content">
            <?php if (!empty($success_message)): ?>
                <div class="alert alert-success"><?php echo $success_message; ?></div>
            <?php endif; ?>

            <?php if (!empty($error_message)): ?>
                <div class="alert alert-danger"><?php echo $error_message; ?></div>
            <?php endif; ?>

            <!-- 发放优惠券表单 -->
            <div class="form-container">
                <h3>发放优惠券</h3>
                <?php if (!$has_coupon_campaigns): ?>
                    <div class="alert alert-danger">
                        当前没有可用的优惠券活动。请在促销活动中创建类型为"优惠券"的活动。
                    </div>
                    <div class="form-actions">
                        <a href="promotion.php?action=add&preset_type=1&coupon_mode=1" class="btn btn-primary">创建满减券活动</a>
                        <a href="promotion.php?action=add&preset_type=2&coupon_mode=1" class="btn btn-primary" style="margin-left: 10px;">创建折扣券活动</a>
                    </div>
                <?php else: ?>
                    <form method="post" action="">
                        <div class="form-group">
                            <label for="campaign_id">选择优惠券活动 <span class="text-danger">*</span></label>
                            <select name="campaign_id" id="campaign_id" required>
                                <option value="">-- 请选择优惠券活动 --</option>
                                <?php foreach ($coupon_campaigns as $cam): ?>
                                    <option value="<?php echo $cam['id']; ?>">
                                        <?php
                                        echo htmlspecialchars($cam['name']) . ' - ';
                                        echo $cam['discount_type'] == 1
                                            ? "满{$cam['min_amount']}减{$cam['discount_value']}"
                                            : ($cam['discount_value'] * 10) . "折";
                                        ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label>发放对象</label>
                            <div>
                                <div class="checkbox-item">
                                    <label>
                                        <input type="radio" id="issue_all" name="issue_type" value="all" checked>
                                        所有会员
                                    </label>
                                </div>
                                <div class="checkbox-item">
                                    <label>
                                        <input type="radio" id="issue_level" name="issue_type" value="level">
                                        指定等级
                                    </label>
                                </div>
                                <div class="checkbox-item">
                                    <label>
                                        <input type="radio" id="issue_member" name="issue_type" value="member">
                                        指定会员
                                    </label>
                                </div>
                            </div>
                        </div>

                        <div class="form-group" id="level_select_group" style="display: none;">
                            <label for="member_level_id">会员等级</label>
                            <select name="member_level_id" id="member_level_id">
                                <option value="">-- 请选择会员等级 --</option>
                                <?php foreach ($member_levels as $level): ?>
                                    <option value="<?php echo $level['id']; ?>"><?php echo htmlspecialchars($level['level_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group" id="member_select_group" style="display: none;">
                            <label for="member_id">会员ID</label>
                            <input type="number" name="member_id" id="member_id" min="1" placeholder="输入会员ID">
                        </div>

                        <div class="form-actions">
                            <button type="submit" name="issue_coupon" class="btn btn-primary">发放优惠券</button>
                            <a href="promotion.php?action=add&preset_type=1&coupon_mode=1" class="btn btn-secondary">创建新优惠券活动</a>
                        </div>
                    </form>
                <?php endif; ?>
            </div>

            <!-- 优惠券查询表单 -->
            <div class="filter-form">
                <h3>优惠券查询</h3>
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="member_id">会员ID</label>
                            <input type="number" id="member_id" name="member_id" value="<?php echo $member_id; ?>" min="0">
                        </div>
                        <div class="filter-item">
                            <label for="campaign_id">优惠券活动</label>
                            <select id="campaign_id" name="campaign_id">
                                <option value="0">全部活动</option>
                                <?php foreach ($coupon_campaigns as $cam): ?>
                                    <option value="<?php echo $cam['id']; ?>" <?php echo $campaign_id == $cam['id'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($cam['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="is_used">使用状态</label>
                            <select id="is_used" name="is_used">
                                <option value="-1" <?php echo $is_used == -1 ? 'selected' : ''; ?>>全部</option>
                                <option value="0" <?php echo $is_used == 0 ? 'selected' : ''; ?>>未使用</option>
                                <option value="1" <?php echo $is_used == 1 ? 'selected' : ''; ?>>已使用</option>
                            </select>
                        </div>
                        <div class="filter-item" style="display: flex; align-items: flex-end;">
                            <button type="submit" class="btn btn-primary">查询</button>
                            <a href="coupon.php" class="btn btn-secondary" style="margin-left: 10px;">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 优惠券列表 -->
            <div class="table-container">
                <div style="text-align: right; margin-bottom: 10px;">
                    <strong>共查询到 <?php echo $total_records; ?> 张优惠券</strong>
                </div>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>优惠券码</th>
                            <th>会员信息</th>
                            <th>优惠券活动</th>
                            <th>优惠内容</th>
                            <th>领取时间</th>
                            <th>使用状态</th>
                            <th>使用时间</th>
                            <th>关联订单</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (count($coupons) > 0): ?>
                            <?php foreach ($coupons as $coupon): ?>
                                <tr>
                                    <td><?php echo $coupon['id']; ?></td>
                                    <td><?php echo $coupon['code']; ?></td>
                                    <td>
                                        <?php echo htmlspecialchars($coupon['member_name']); ?><br>
                                        <?php echo $coupon['member_phone']; ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($coupon['campaign_name']); ?></td>
                                    <td>
                                        <?php
                                        if ($coupon['discount_type'] == 1) {
                                            echo "满{$coupon['min_amount']}减{$coupon['discount_value']}";
                                        } else {
                                            echo ($coupon['discount_value'] * 10) . "折";
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo substr($coupon['create_time'], 0, 16); ?></td>
                                    <td>
                                        <?php if ($coupon['is_used'] == 1): ?>
                                            <span class="status-inactive">已使用</span>
                                        <?php else: ?>
                                            <span class="status-active">未使用</span>
                                        <?php endif; ?>
                                    </td>
                                    <td><?php echo $coupon['used_time'] ? substr($coupon['used_time'], 0, 16) : '-'; ?></td>
                                    <td>
                                        <?php if ($coupon['order_id']): ?>
                                            <a href="../order/detail.php?id=<?php echo $coupon['order_id']; ?>" class="btn btn-sm btn-secondary">查看订单</a>
                                        <?php else: ?>
                                            -
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无优惠券数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分页 -->
            <?php if ($total_pages > 1): ?>
                <div class="pagination">
                    <?php if ($page > 1): ?>
                        <a href="?page=1&member_id=<?php echo $member_id; ?>&campaign_id=<?php echo $campaign_id; ?>&is_used=<?php echo $is_used; ?>" class="page-link">首页</a>
                        <a href="?page=<?php echo $page - 1; ?>&member_id=<?php echo $member_id; ?>&campaign_id=<?php echo $campaign_id; ?>&is_used=<?php echo $is_used; ?>" class="page-link">上一页</a>
                    <?php endif; ?>

                    <?php
                    $startPage = max(1, $page - 2);
                    $endPage = min($total_pages, $page + 2);

                    for ($i = $startPage; $i <= $endPage; $i++):
                    ?>
                        <a href="?page=<?php echo $i; ?>&member_id=<?php echo $member_id; ?>&campaign_id=<?php echo $campaign_id; ?>&is_used=<?php echo $is_used; ?>" class="page-link <?php echo $i == $page ? 'current' : ''; ?>"><?php echo $i; ?></a>
                    <?php endfor; ?>

                    <?php if ($page < $total_pages): ?>
                        <a href="?page=<?php echo $page + 1; ?>&member_id=<?php echo $member_id; ?>&campaign_id=<?php echo $campaign_id; ?>&is_used=<?php echo $is_used; ?>" class="page-link">下一页</a>
                        <a href="?page=<?php echo $total_pages; ?>&member_id=<?php echo $member_id; ?>&campaign_id=<?php echo $campaign_id; ?>&is_used=<?php echo $is_used; ?>" class="page-link">末页</a>
                    <?php endif; ?>
                </div>
                <div class="pagination-info">
                    共 <?php echo $total_records; ?> 条记录，当前 <?php echo $page; ?>/<?php echo $total_pages; ?> 页
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 发放优惠券选项切换
        document.addEventListener('DOMContentLoaded', function() {
            const issueTypeRadios = document.querySelectorAll('input[name="issue_type"]');
            const levelSelectGroup = document.getElementById('level_select_group');
            const memberSelectGroup = document.getElementById('member_select_group');

            function handleRadioChange() {
                const selectedValue = document.querySelector('input[name="issue_type"]:checked').value;

                if (selectedValue === 'all') {
                    levelSelectGroup.style.display = 'none';
                    memberSelectGroup.style.display = 'none';
                } else if (selectedValue === 'level') {
                    levelSelectGroup.style.display = 'block';
                    memberSelectGroup.style.display = 'none';
                } else if (selectedValue === 'member') {
                    levelSelectGroup.style.display = 'none';
                    memberSelectGroup.style.display = 'block';
                }
            }

            issueTypeRadios.forEach(radio => {
                radio.addEventListener('change', handleRadioChange);
            });

            // 初始状态
            handleRadioChange();
        });
    </script>
</body>

</html>