<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('marketing');

// 记录访问日志
record_log('访问营销推广页面');

// 获取活动数量统计
$stmt = $pdo->query("SELECT COUNT(*) as count FROM marketing_campaigns WHERE status = 1");
$active_campaigns = $stmt->fetch()['count'];

// 获取优惠券数量统计
$stmt = $pdo->query("SELECT COUNT(*) as count FROM member_coupons WHERE is_used = 0");
$active_coupons = $stmt->fetch()['count'];

// 获取近期活动
$stmt = $pdo->query("
    SELECT id, name, type, start_time, end_time, status 
    FROM marketing_campaigns 
    ORDER BY create_time DESC 
    LIMIT 5
");
$recent_campaigns = $stmt->fetchAll();

// 获取模板数量
$stmt = $pdo->query("SELECT COUNT(*) as count FROM marketing_templates");
$templates_count = $stmt->fetch()['count'];
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>营销推广</h2>
        </div>

        <div class="content">
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>营销活动</h3>
                    <div class="number"><?php echo $active_campaigns; ?></div>
                    <div class="desc">进行中的活动</div>
                </div>

                <div class="dashboard-card">
                    <h3>未使用优惠券</h3>
                    <div class="number"><?php echo $active_coupons; ?></div>
                    <div class="desc">会员未使用优惠券数量</div>
                </div>

                <div class="dashboard-card">
                    <h3>消息模板</h3>
                    <div class="number"><?php echo $templates_count; ?></div>
                    <div class="desc">可用的营销消息模板</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="campaign.php" class="function-link">
                    <h3>促销活动</h3>
                </a>
                <a href="coupon.php" class="function-link">
                    <h3>优惠券管理</h3>
                </a>
                <a href="referral.php" class="function-link">
                    <h3>推荐返利</h3>
                </a>
                <a href="message.php" class="function-link">
                    <h3>短信/邮件营销</h3>
                </a>
            </div>

            <h2>近期活动</h2>
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>活动名称</th>
                            <th>活动类型</th>
                            <th>开始时间</th>
                            <th>结束时间</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (!empty($recent_campaigns)): ?>
                            <?php foreach ($recent_campaigns as $campaign): ?>
                                <tr>
                                    <td><?php echo $campaign['id']; ?></td>
                                    <td><?php echo htmlspecialchars($campaign['name']); ?></td>
                                    <td><?php echo get_campaign_type_name($campaign['type']); ?></td>
                                    <td><?php echo $campaign['start_time']; ?></td>
                                    <td><?php echo $campaign['end_time']; ?></td>
                                    <td>
                                        <?php if ($campaign['status'] == 1): ?>
                                            <span class="status-active">启用</span>
                                        <?php else: ?>
                                            <span class="status-inactive">禁用</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <a href="campaign_detail.php?id=<?php echo $campaign['id']; ?>" class="btn btn-sm btn-secondary">详情</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无活动数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>
<?php
// 活动类型名称
function get_campaign_type_name($type)
{
    $types = [
        1 => '满减券',
        2 => '折扣券',
        3 => '限时优惠',
        4 => '套餐促销',
        5 => '充值送礼',
        6 => '节日促销',
        7 => '推荐返利'
    ];
    return $types[$type] ?? '未知类型';
}
?>