<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('marketing');

// 记录访问日志
record_log('访问短信/邮件营销页面');

// 初始化变量
$message = '';
$error = '';
$action = isset($_GET['action']) ? $_GET['action'] : 'list';
$template_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

// 处理模板保存
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['save_template'])) {
    $template_name = isset($_POST['name']) ? trim($_POST['name']) : '';
    $template_type = isset($_POST['type']) ? intval($_POST['type']) : 1;
    $template_subject = isset($_POST['subject']) ? trim($_POST['subject']) : '';
    $template_content = isset($_POST['content']) ? trim($_POST['content']) : '';
    $template_status = isset($_POST['status']) ? 1 : 0;
    $edit_id = isset($_POST['id']) ? intval($_POST['id']) : 0;

    if (empty($template_name)) {
        $error = '模板名称不能为空';
    } elseif (empty($template_content)) {
        $error = '模板内容不能为空';
    } elseif ($template_type == 2 && empty($template_subject)) {
        $error = '邮件主题不能为空';
    } else {
        try {
            $pdo->beginTransaction();

            if ($edit_id > 0) {
                // 更新现有模板
                $stmt = $pdo->prepare("
                    UPDATE marketing_templates
                    SET name = :name,
                        type = :type,
                        subject = :subject,
                        content = :content,
                        status = :status
                    WHERE id = :id
                ");
                $stmt->execute([
                    ':name' => $template_name,
                    ':type' => $template_type,
                    ':subject' => $template_subject,
                    ':content' => $template_content,
                    ':status' => $template_status,
                    ':id' => $edit_id
                ]);
                $message = '消息模板已更新';
            } else {
                // 创建新模板
                $stmt = $pdo->prepare("
                    INSERT INTO marketing_templates (
                        name, type, subject, content, status, create_time
                    ) VALUES (
                        :name, :type, :subject, :content, :status, NOW()
                    )
                ");
                $stmt->execute([
                    ':name' => $template_name,
                    ':type' => $template_type,
                    ':subject' => $template_subject,
                    ':content' => $template_content,
                    ':status' => $template_status
                ]);
                $message = '新消息模板已创建';
            }

            $pdo->commit();
            $action = 'list'; // 返回列表
        } catch (Exception $e) {
            $pdo->rollBack();
            $error = '保存模板失败: ' . $e->getMessage();
        }
    }
}

// 处理发送消息
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['send_message'])) {
    $send_template_id = isset($_POST['template_id']) ? intval($_POST['template_id']) : 0;
    $send_target = isset($_POST['send_target']) ? $_POST['send_target'] : '';
    $send_member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;
    $send_level_id = isset($_POST['level_id']) ? intval($_POST['level_id']) : 0;

    if ($send_template_id <= 0) {
        $error = '请选择要发送的消息模板';
    } elseif (empty($send_target)) {
        $error = '请选择发送目标';
    } elseif ($send_target == 'member' && $send_member_id <= 0) {
        $error = '请选择要发送的会员';
    } elseif ($send_target == 'level' && $send_level_id <= 0) {
        $error = '请选择要发送的会员等级';
    } else {
        try {
            // 获取模板信息
            $stmt = $pdo->prepare("SELECT * FROM marketing_templates WHERE id = ?");
            $stmt->execute([$send_template_id]);
            $template = $stmt->fetch();

            if (!$template) {
                throw new Exception('消息模板不存在');
            }

            // 根据不同目标获取会员列表
            $members = [];
            if ($send_target == 'member') {
                $stmt = $pdo->prepare("SELECT id, name, phone FROM members WHERE id = ?");
                $stmt->execute([$send_member_id]);
                $members = $stmt->fetchAll();
            } elseif ($send_target == 'level') {
                $stmt = $pdo->prepare("SELECT id, name, phone FROM members WHERE level_id = ?");
                $stmt->execute([$send_level_id]);
                $members = $stmt->fetchAll();
            } elseif ($send_target == 'all') {
                $stmt = $pdo->query("SELECT id, name, phone FROM members WHERE status = 1");
                $members = $stmt->fetchAll();
            } elseif ($send_target == 'birthday') {
                $stmt = $pdo->query("
                    SELECT id, name, phone 
                    FROM members 
                    WHERE status = 1 
                    AND MONTH(birthday) = MONTH(CURDATE())
                ");
                $members = $stmt->fetchAll();
            }

            // 记录消息发送
            $sent_count = 0;
            foreach ($members as $member) {
                // 在实际环境中，这里应该调用短信/邮件API发送消息
                // 这里仅作为示例，记录发送历史
                $content = str_replace(
                    ['{name}', '{id}'],
                    [$member['name'], $member['id']],
                    $template['content']
                );

                $stmt = $pdo->prepare("
                    INSERT INTO sys_logs (
                        user_id, username, operation, ip
                    ) VALUES (
                        ?, ?, ?, ?
                    )
                ");
                $stmt->execute([
                    0, // 系统发送
                    'system',
                    sprintf(
                        '向会员 %s(ID:%d) 发送%s：%s',
                        $member['name'],
                        $member['id'],
                        $template['type'] == 1 ? '短信' : '邮件',
                        substr($content, 0, 100) . (strlen($content) > 100 ? '...' : '')
                    ),
                    get_client_ip()
                ]);
                $sent_count++;
            }

            $message = sprintf(
                '成功发送%s给 %d 位会员',
                $template['type'] == 1 ? '短信' : '邮件',
                $sent_count
            );
            $action = 'list'; // 返回列表
        } catch (Exception $e) {
            $error = '发送消息失败: ' . $e->getMessage();
        }
    }
}

// 处理删除模板
if ($action == 'delete' && $template_id > 0) {
    try {
        $stmt = $pdo->prepare("DELETE FROM marketing_templates WHERE id = ?");
        $stmt->execute([$template_id]);
        $message = '消息模板已删除';
        $action = 'list';
    } catch (Exception $e) {
        $error = '删除模板失败: ' . $e->getMessage();
    }
}

// 获取单个模板
$template = null;
if (($action == 'edit' || $action == 'view') && $template_id > 0) {
    $stmt = $pdo->prepare("SELECT * FROM marketing_templates WHERE id = ?");
    $stmt->execute([$template_id]);
    $template = $stmt->fetch();

    if (!$template) {
        $error = '消息模板不存在';
        $action = 'list';
    }
}

// 获取模板列表
$templates = [];
if ($action == 'list' || $action == 'send') {
    $stmt = $pdo->query("SELECT * FROM marketing_templates ORDER BY type, create_time DESC");
    $templates = $stmt->fetchAll();
}

// 获取会员等级列表
$member_levels = [];
if ($action == 'send') {
    $stmt = $pdo->query("SELECT id, level_name FROM member_levels ORDER BY min_points");
    $member_levels = $stmt->fetchAll();

    // 获取会员列表，用于指定会员下拉框
    $stmt = $pdo->query("SELECT id, name, phone FROM members WHERE status = 1 ORDER BY id DESC LIMIT 100");
    $all_members = $stmt->fetchAll();
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>短信/邮件营销</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>短信/邮件营销</h2>
            <div class="breadcrumb">
                <a href="index.php">营销推广</a> &gt;
                <span>短信/邮件营销</span>
            </div>
        </div>

        <div class="content">
            <?php if ($message): ?>
                <div class="alert alert-success"><?php echo $message; ?></div>
            <?php endif; ?>

            <?php if ($error): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if ($action == 'list'): ?>
                <!-- 模板列表 -->
                <div class="action-bar">
                    <a href="?action=add" class="btn btn-primary">添加模板</a>
                    <a href="?action=send" class="btn btn-success">发送消息</a>
                </div>

                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>模板名称</th>
                                <th>类型</th>
                                <th>主题</th>
                                <th>状态</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($templates)): ?>
                                <?php foreach ($templates as $t): ?>
                                    <tr>
                                        <td><?php echo $t['id']; ?></td>
                                        <td><?php echo htmlspecialchars($t['name']); ?></td>
                                        <td><?php echo $t['type'] == 1 ? '短信' : '邮件'; ?></td>
                                        <td><?php echo $t['type'] == 2 ? htmlspecialchars($t['subject']) : '-'; ?></td>
                                        <td>
                                            <?php if ($t['status'] == 1): ?>
                                                <span class="status-active">启用</span>
                                            <?php else: ?>
                                                <span class="status-inactive">禁用</span>
                                            <?php endif; ?>
                                        </td>
                                        <td><?php echo substr($t['create_time'], 0, 16); ?></td>
                                        <td>
                                            <a href="?action=view&id=<?php echo $t['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                            <a href="?action=edit&id=<?php echo $t['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                            <a href="?action=delete&id=<?php echo $t['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除该模板吗？')">删除</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无模板数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <div class="info-box">
                    <h3>提示说明</h3>
                    <ul>
                        <li>模板内容中可以使用变量占位符，如 {name} 表示会员姓名</li>
                        <li>常用变量：{name} 会员姓名, {id} 会员ID, {store_name} 门店名称, {order_no} 订单编号等</li>
                        <li>邮件模板需要填写主题，短信模板无需填写主题</li>
                    </ul>
                </div>

            <?php elseif ($action == 'add' || $action == 'edit'): ?>
                <!-- 添加/编辑模板 -->
                <div class="section-panel">
                    <div class="section-header">
                        <h3><?php echo $action == 'add' ? '添加模板' : '编辑模板'; ?></h3>
                    </div>
                    <div class="section-body">
                        <form action="" method="post" class="form">
                            <?php if ($action == 'edit'): ?>
                                <input type="hidden" name="id" value="<?php echo $template['id']; ?>">
                            <?php endif; ?>

                            <div class="form-group">
                                <label for="name">模板名称：</label>
                                <input type="text" id="name" name="name" value="<?php echo $action == 'edit' ? htmlspecialchars($template['name']) : ''; ?>" class="form-control" required>
                            </div>

                            <div class="form-group">
                                <label for="type">消息类型：</label>
                                <select id="type" name="type" class="form-control" onchange="toggleSubject()">
                                    <option value="1" <?php echo ($action == 'edit' && $template['type'] == 1) ? 'selected' : ''; ?>>短信</option>
                                    <option value="2" <?php echo ($action == 'edit' && $template['type'] == 2) ? 'selected' : ''; ?>>邮件</option>
                                </select>
                            </div>

                            <div id="subject_div" class="form-group" style="<?php echo ($action == 'edit' && $template['type'] == 1) ? 'display:none;' : ''; ?>">
                                <label for="subject">邮件主题：</label>
                                <input type="text" id="subject" name="subject" value="<?php echo $action == 'edit' ? htmlspecialchars($template['subject']) : ''; ?>" class="form-control">
                                <div class="form-help">仅邮件类型需要填写主题</div>
                            </div>

                            <div class="form-group">
                                <label for="content">模板内容：</label>
                                <textarea id="content" name="content" rows="6" class="form-control" required><?php echo $action == 'edit' ? htmlspecialchars($template['content']) : ''; ?></textarea>
                                <div class="form-help">可使用变量：{name} 会员姓名, {id} 会员ID, {order_no} 订单编号等</div>
                            </div>

                            <div class="form-group">
                                <div class="checkbox-item">
                                    <label>
                                        <input type="checkbox" name="status" value="1" <?php echo ($action == 'edit' && $template['status'] == 1) ? 'checked' : 'checked'; ?>> 启用该模板
                                    </label>
                                </div>
                            </div>

                            <div class="form-actions">
                                <button type="submit" name="save_template" class="btn btn-primary">保存模板</button>
                                <a href="?action=list" class="btn btn-secondary">返回列表</a>
                            </div>
                        </form>
                    </div>
                </div>

            <?php elseif ($action == 'view'): ?>
                <!-- 查看模板 -->
                <div class="section-panel">
                    <div class="section-header">
                        <h3>查看模板</h3>
                    </div>
                    <div class="section-body">
                        <table class="info-table">
                            <tr>
                                <td width="20%">模板ID：</td>
                                <td><?php echo $template['id']; ?></td>
                            </tr>
                            <tr>
                                <td>模板名称：</td>
                                <td><?php echo htmlspecialchars($template['name']); ?></td>
                            </tr>
                            <tr>
                                <td>消息类型：</td>
                                <td><?php echo $template['type'] == 1 ? '短信' : '邮件'; ?></td>
                            </tr>
                            <?php if ($template['type'] == 2): ?>
                                <tr>
                                    <td>邮件主题：</td>
                                    <td><?php echo htmlspecialchars($template['subject']); ?></td>
                                </tr>
                            <?php endif; ?>
                            <tr>
                                <td>模板内容：</td>
                                <td><?php echo nl2br(htmlspecialchars($template['content'])); ?></td>
                            </tr>
                            <tr>
                                <td>状态：</td>
                                <td><?php echo $template['status'] == 1 ? '<span class="status-active">启用</span>' : '<span class="status-inactive">禁用</span>'; ?></td>
                            </tr>
                            <tr>
                                <td>创建时间：</td>
                                <td><?php echo $template['create_time']; ?></td>
                            </tr>
                        </table>

                        <div class="form-actions">
                            <a href="?action=edit&id=<?php echo $template['id']; ?>" class="btn btn-primary">编辑模板</a>
                            <a href="?action=list" class="btn btn-secondary">返回列表</a>
                        </div>
                    </div>
                </div>

            <?php elseif ($action == 'send'): ?>
                <!-- 发送消息 -->
                <div class="section-panel">
                    <div class="section-header">
                        <h3>发送消息</h3>
                    </div>
                    <div class="section-body">
                        <form action="" method="post" class="form">
                            <div class="form-group">
                                <label for="template_id">选择消息模板：</label>
                                <select id="template_id" name="template_id" class="form-control" required>
                                    <option value="">请选择模板</option>
                                    <?php foreach ($templates as $t): ?>
                                        <?php if ($t['status'] == 1): ?>
                                            <option value="<?php echo $t['id']; ?>">
                                                [<?php echo $t['type'] == 1 ? '短信' : '邮件'; ?>] <?php echo htmlspecialchars($t['name']); ?>
                                            </option>
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="form-group">
                                <label>发送目标：</label>
                                <div class="group-items">
                                    <div class="checkbox-item">
                                        <label>
                                            <input type="radio" name="send_target" value="member" onclick="toggleSendTarget('member')"> 指定会员
                                        </label>
                                    </div>
                                    <div class="checkbox-item">
                                        <label>
                                            <input type="radio" name="send_target" value="level" onclick="toggleSendTarget('level')"> 指定会员等级
                                        </label>
                                    </div>
                                    <div class="checkbox-item">
                                        <label>
                                            <input type="radio" name="send_target" value="all" onclick="toggleSendTarget('all')"> 所有会员
                                        </label>
                                    </div>
                                    <div class="checkbox-item">
                                        <label>
                                            <input type="radio" name="send_target" value="birthday" onclick="toggleSendTarget('birthday')"> 本月生日会员
                                        </label>
                                    </div>
                                </div>
                            </div>

                            <div id="member_select" class="form-group" style="display:none;">
                                <label for="member_id">选择会员：</label>
                                <select id="member_id" name="member_id" class="form-control">
                                    <option value="">请选择会员</option>
                                    <?php foreach ($all_members as $m): ?>
                                        <option value="<?php echo $m['id']; ?>"><?php echo htmlspecialchars($m['name']); ?> (<?php echo htmlspecialchars($m['phone']); ?>)</option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div id="level_select" class="form-group" style="display:none;">
                                <label for="level_id">选择会员等级：</label>
                                <select id="level_id" name="level_id" class="form-control">
                                    <option value="">请选择会员等级</option>
                                    <?php foreach ($member_levels as $level): ?>
                                        <option value="<?php echo $level['id']; ?>"><?php echo htmlspecialchars($level['level_name']); ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="form-actions">
                                <button type="submit" name="send_message" class="btn btn-primary">发送消息</button>
                                <a href="?action=list" class="btn btn-secondary">返回列表</a>
                            </div>
                        </form>
                    </div>
                </div>

                <div class="info-box">
                    <h3>注意事项</h3>
                    <ul>
                        <li>批量发送消息可能会产生较大费用，请确认发送内容和目标无误</li>
                        <li>实际发送效果可能受运营商、邮件服务商等外部因素影响</li>
                        <li>为避免打扰会员，请合理控制发送频率</li>
                    </ul>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        function toggleSubject() {
            var type = document.getElementById('type').value;
            var subjectDiv = document.getElementById('subject_div');
            if (type == '1') { // 短信
                subjectDiv.style.display = 'none';
            } else { // 邮件
                subjectDiv.style.display = 'block';
            }
        }

        function toggleSendTarget(target) {
            document.getElementById('member_select').style.display = target === 'member' ? 'block' : 'none';
            document.getElementById('level_select').style.display = target === 'level' ? 'block' : 'none';
        }
    </script>
</body>

</html>