<?php
// order/index.php - 订单管理首页
session_start();
require_once '../database_config.php';

// 检查用户是否有订单管理权限
check_permission_or_die('order.view');

// 获取订单总数
$stmt = $pdo->query("SELECT COUNT(*) as total FROM orders");
$orderCount = $stmt->fetch()['total'];

// 获取今日订单
$today = date('Y-m-d');
$stmt = $pdo->prepare("SELECT COUNT(*) as count, SUM(actual_amount) as amount FROM orders WHERE DATE(create_time) = ?");
$stmt->execute([$today]);
$todayStats = $stmt->fetch();
$todayOrderCount = $todayStats['count'] ?: 0;
$todayOrderAmount = $todayStats['amount'] ?: 0;

// 获取不同状态的订单数量
$stmt = $pdo->query("
    SELECT 
        SUM(CASE WHEN status = 1 THEN 1 ELSE 0 END) as pending_payment,
        SUM(CASE WHEN status = 2 THEN 1 ELSE 0 END) as paid,
        SUM(CASE WHEN status = 3 THEN 1 ELSE 0 END) as pending_delivery,
        SUM(CASE WHEN status = 4 THEN 1 ELSE 0 END) as completed,
        SUM(CASE WHEN status = 5 THEN 1 ELSE 0 END) as cancelled,
        SUM(CASE WHEN status = 6 THEN 1 ELSE 0 END) as refunding,
        SUM(CASE WHEN status = 7 THEN 1 ELSE 0 END) as refunded
    FROM orders
");
$statusStats = $stmt->fetch();

// 获取待处理的退款订单数
$stmt = $pdo->query("SELECT COUNT(*) FROM order_refunds WHERE status = 1");
$pendingRefunds = $stmt->fetchColumn();

// 获取最近的订单
$stmt = $pdo->query("
    SELECT o.*, m.name as member_name
    FROM orders o
    LEFT JOIN members m ON o.member_id = m.id
    ORDER BY o.create_time DESC LIMIT 5
");
$recentOrders = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>订单管理 - <?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单管理</h2>
        </div>

        <div class="content">
            <!-- 数据概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>订单总数</h3>
                    <div class="number"><?php echo $orderCount; ?></div>
                    <div class="desc">系统中的订单数量</div>
                </div>
                <div class="dashboard-card">
                    <h3>今日订单</h3>
                    <div class="number"><?php echo $todayOrderCount; ?></div>
                    <div class="desc">金额：￥<?php echo number_format($todayOrderAmount, 2); ?></div>
                </div>
                <div class="dashboard-card">
                    <h3>待支付订单</h3>
                    <div class="number"><?php echo $statusStats['pending_payment']; ?></div>
                    <div class="desc">需要处理的支付</div>
                </div>
                <div class="dashboard-card">
                    <h3>待处理退款</h3>
                    <div class="number"><?php echo $pendingRefunds; ?></div>
                    <div class="desc">需要审核的退款申请</div>
                </div>
            </div>

            <!-- 功能链接 -->
            <div class="function-links">
                <a href="list.php" class="function-link">
                    <h3>订单列表</h3>
                </a>
                <a href="payment.php" class="function-link">
                    <h3>订单支付</h3>
                </a>
                <a href="status.php" class="function-link">
                    <h3>订单状态</h3>
                </a>
                <a href="refund.php" class="function-link">
                    <h3>退款管理</h3>
                </a>
            </div>

            <!-- 订单状态分布 -->
            <h3>订单状态分布</h3>
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>状态</th>
                            <th>订单数量</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>待付款</td>
                            <td><?php echo $statusStats['pending_payment']; ?></td>
                            <td><a href="list.php?status=1" class="btn btn-sm btn-primary">查看</a></td>
                        </tr>
                        <tr>
                            <td>已付款</td>
                            <td><?php echo $statusStats['paid']; ?></td>
                            <td><a href="list.php?status=2" class="btn btn-sm btn-primary">查看</a></td>
                        </tr>
                        <tr>
                            <td>待配送</td>
                            <td><?php echo $statusStats['pending_delivery']; ?></td>
                            <td><a href="list.php?status=3" class="btn btn-sm btn-primary">查看</a></td>
                        </tr>
                        <tr>
                            <td>已完成</td>
                            <td><?php echo $statusStats['completed']; ?></td>
                            <td><a href="list.php?status=4" class="btn btn-sm btn-primary">查看</a></td>
                        </tr>
                        <tr>
                            <td>已取消</td>
                            <td><?php echo $statusStats['cancelled']; ?></td>
                            <td><a href="list.php?status=5" class="btn btn-sm btn-primary">查看</a></td>
                        </tr>
                        <tr>
                            <td>退款中</td>
                            <td><?php echo $statusStats['refunding']; ?></td>
                            <td><a href="list.php?status=6" class="btn btn-sm btn-primary">查看</a></td>
                        </tr>
                        <tr>
                            <td>已退款</td>
                            <td><?php echo $statusStats['refunded']; ?></td>
                            <td><a href="list.php?status=7" class="btn btn-sm btn-primary">查看</a></td>
                        </tr>
                    </tbody>
                </table>
            </div>

            <!-- 最近订单 -->
            <h3>最近订单</h3>
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>订单号</th>
                            <th>会员</th>
                            <th>金额</th>
                            <th>状态</th>
                            <th>下单时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($recentOrders as $order): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                <td><?php echo (empty($order['member_name']) ? '非会员' : htmlspecialchars($order['member_name'])); ?></td>
                                <td>￥<?php echo number_format($order['actual_amount'], 2); ?></td>
                                <td>
                                    <?php
                                    $status_text = '';
                                    $status_class = '';

                                    switch ($order['status']) {
                                        case 1:
                                            $status_text = '待付款';
                                            $status_class = 'text-warning';
                                            break;
                                        case 2:
                                            $status_text = '已付款';
                                            $status_class = 'text-primary';
                                            break;
                                        case 3:
                                            $status_text = '待配送';
                                            $status_class = 'text-info';
                                            break;
                                        case 4:
                                            $status_text = '已完成';
                                            $status_class = 'status-active';
                                            break;
                                        case 5:
                                            $status_text = '已取消';
                                            $status_class = 'status-inactive';
                                            break;
                                        case 6:
                                            $status_text = '退款中';
                                            $status_class = 'text-warning';
                                            break;
                                        case 7:
                                            $status_text = '已退款';
                                            $status_class = 'status-inactive';
                                            break;
                                    }
                                    echo '<span class="' . $status_class . '">' . $status_text . '</span>';
                                    ?>
                                </td>
                                <td><?php echo date('Y-m-d H:i', strtotime($order['create_time'])); ?></td>
                                <td>
                                    <a href="list.php?action=view&id=<?php echo $order['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                    <a href="list.php?action=edit&id=<?php echo $order['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($recentOrders)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无订单数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>